@@ -3,7 +3,7 @@ use warnings;
 
 package Test::MethodFixtures;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Carp;
 use Hook::LexWrap qw( wrap );
@@ -101,7 +101,7 @@ sub retrieve {
         die "Nothing stored for " . $args->{method};
     }
 
-    return $stored->{output};
+    return $stored;
 }
 
 sub _compare_versions {
@@ -134,64 +134,68 @@ sub mock {
 
     while ( my ( $name, $value ) = splice @_, 0, 2 ) {
 
-        my $get_key = _get_key_sub($value);
+        my $original_fn = \&{$name};
 
-        my $pre = sub {
+        my $key_sub = _get_key_sub($value);
 
-            my $mode = $self_ref->mode;
+        $self->_wrapped->{$name} = wrap $name, pre => sub {
 
-            return if $mode eq 'record' or $mode eq 'passthrough';
-
-            my @args = @_;    # original arguments that method received
-            pop @args;        # currently undef, will be the return value
-
-            my $key = $get_key->( { wantarray => wantarray() }, @args );
-
-            # add cached value into extra arg,
-            # so original sub will not be called
-            my $retrieved = eval {
-                $self_ref->retrieve(
-                    {   method => $name,
-                        key    => $key,
-                        input  => \@args,
-                    }
-                );
-            };
-            if ($@) {
-                croak "Unable to retrieve $name - in $mode mode: $@"
-                    unless $mode eq 'auto';
-            } else {
-                $_[-1] = $retrieved;
-            }
-        };
-
-        my $post = sub {
             my $mode = $self_ref->mode;
 
             return if $mode eq 'passthrough';
 
-            croak "Problem retrieving data - reached store() in $mode mode"
-                if $mode eq 'playback';
+            my @args = @_;    # original arguments that method received
+            pop @args;        # currently undef, will be the return value
 
-            my (@args) = @_;    # origin arguments method received, plus result
-            my $result = pop @args;
+            my $key = $key_sub->( { wantarray => wantarray() }, @args );
 
-            my $key = $get_key->( { wantarray => wantarray() }, @args );
+            if ( $mode eq 'playback' or $mode eq 'auto' ) {
 
-            $self_ref->store(
-                {   method => $name,
-                    key    => $key,
-                    input  => \@args,
-                    defined wantarray()
-                    ? ( output => $result )
-                    : ( no_output => 1 ),
+                my $retrieved = eval {
+                    $self_ref->retrieve(
+                        {   method => $name,
+                            key    => $key,
+                            input  => \@args,
+                        }
+                    );
+                };
+                if ($@) {
+                    croak "Unable to retrieve $name - in $mode mode: $@"
+                        unless $mode eq 'auto';
+                } else {
+
+                    # add cached value into extra arg,
+                    # so original sub will not be called
+                    $_[-1] = $retrieved->{output};
+                    return;
                 }
-            );
-        };
+            }
 
-        $self->_wrapped->{$name} = wrap $name,    #
-            pre  => $pre,                         #
-            post => $post;
+            if ( $mode eq 'record' or $mode eq 'auto' ) {
+
+                my $result;
+                if (wantarray) {
+                    $result = [ $original_fn->(@args) ];
+                } elsif ( defined wantarray ) {
+                    $result = $original_fn->(@args);
+                } else {
+                    $original_fn->(@args);
+                }
+
+                $self_ref->store(
+                    {   method => $name,
+                        key    => $key,
+                        input  => \@args,
+                        defined wantarray()
+                        ? ( output => $result )
+                        : ( no_output => 1 ),
+                    }
+                );
+
+                $_[-1] = $result;
+                return;
+            }
+        };
     }
 
     return $self;
@@ -290,6 +294,11 @@ More configuration options:
         }
     );
 
+=head1 BREAKING CHANGE
+
+v0.07 - the default file storage now uses hyphens instead of colons as package
+name separators.
+
 
 =head1 DESCRIPTION
 
@@ -300,8 +309,8 @@ non-repeatable call, so that there is no need to make that call again during
 subsequent testing.
 
 This module aims to be low-dependency to minimise disruption with legacy
-codebases.  By default tries to use L<Test::MethodFixtures::Storage::File> to
-record method data.  Other storage classes can be provided instead, to use
+codebases.  By default it tries to use L<Test::MethodFixtures::Storage::File>
+to record method data.  Other storage classes can be provided instead, to use
 modules available to your system.
 
 B<N.B.> This module should be considered ALPHA quality and liable to change.
@@ -312,6 +321,17 @@ The name is inspired by database 'fixtures'.
 
 Feedback welcome!
 
+=head1 ATTRIBUTES
+
+=head2 mode
+
+Valid modes are C<record>, C<playback>, C<auto>, and C<passthrough>. See
+C<mock()>.
+
+=head2 storage
+
+A L<Test::MethodFixtures::Storage> object.
+
 =head1 METHODS
 
 =head2 new
@@ -335,11 +355,15 @@ Class method. Constructor
     $mocker->mock("Their::Package::method");
     $mocker->mock( "Their::Package::method", sub { ( $_[0], ... ) } );
 
-In C<record> mode stores the return values of the named method against the
-arguments passed through to generate those return values.
+In C<record> mode C<mock()> stores the return values of the named method
+against the arguments passed through to generate those return values.
 
-In C<playback> mode retrieves stored return values of the named method for the
-arguments passed in.
+In C<playback> mode C<mock()> retrieves stored return values of the named
+method for the arguments passed in.
+
+In C<auto> mode C<mock()> either stores or retrieves values, depending on
+their presence in the saved data. This mode is useful for adding tests
+without the need to re-record the other calls.
 
 In C<passthrough> mode the arguments and return values are passed to and from
 the method as normal (i.e. turns off mocking).
